@@ -189,7 +189,7 @@ class GenerateCitationNet():
         dfOut.insert(0, 'type', 'citation')
         return dfOut, (time.time() - start_time)
 
-    def getReferenceDF(self, doi):
+    def getReferenceDF(self, doi, debug=False):
         flDict = {
             'rows': 1,
             'fl': 'DOI, reference-count, is-referenced-by-count, author.family,\
@@ -237,22 +237,31 @@ class GenerateCitationNet():
                         outputDict.update({unstrIndex: elem})
                     except ValueError:
                         pass
-                dfOut = pd.DataFrame(outputDict).transpose()
+                if debug:
+                    print(outputDict)
+                dfOut = pd.DataFrame([outputDict]).transpose()
                 dfOut = dfOut.reset_index().rename(
                     columns={'index': 'targetFull'}
                     )
-                dfOut.insert(
-                    0,
-                    'altTargetYear',
-                    dfOut.targetFull.apply(lambda row: self.findYear(row))
-                    )
-                dfOut.targetYear.replace(
-                    r'^\s*$', np.nan, regex=True, inplace=True
-                    )
-                dfOut.targetYear.fillna(
-                    value=dfOut.altTargetYear, inplace=True
-                    )
-                dfOut = dfOut.drop('altTargetYear', axis=1)
+                if 'targetYear' in dfOut.columns:
+                    dfOut.insert(
+                        0,
+                        'altTargetYear',
+                        dfOut.targetFull.apply(lambda row: self.findYear(row))
+                        )
+                    dfOut.targetYear.replace(
+                        r'^\s*$', np.nan, regex=True, inplace=True
+                        )
+                    dfOut.targetYear.fillna(
+                        value=dfOut.altTargetYear, inplace=True
+                        )
+                    dfOut = dfOut.drop('altTargetYear', axis=1)
+                else:
+                    dfOut.insert(
+                        0,
+                        'targetYear',
+                        dfOut.targetFull.apply(lambda row: self.findYear(row))
+                        )
             except KeyError:
                 print('Could not find data for {0} references.'.format(
                      ref_count - doi_count)
@@ -372,12 +381,13 @@ class GenerateCitationNet():
             if level == 2 & len(dfRes) >= 0:
                 if debug:
                     print(f'Got {dfRes.shape[0]} citations, looking for second level.')
-                newDFs = [dfRes]
-                for elem in dfRes.sourceDOI.values:
-                    dfResTemp, runtime = self.getCitationsDF(elem)
-                    runtimeTotal.append(runtime)
-                    newDFs.append(dfResTemp)
-                dfRes = pd.concat(newDFs, ignore_index=True)
+                if 'sourceDOI' in dfRes.columns:
+                    newDFs = [dfRes]
+                    for elem in dfRes.sourceDOI.values:
+                        dfResTemp, runtime = self.getCitationsDF(elem)
+                        runtimeTotal.append(runtime)
+                        newDFs.append(dfResTemp)
+                    dfRes = pd.concat(newDFs, ignore_index=True)
                 if debug:
                     print(f'Cite: Runtime {sum(runtimeTotal)} sec.')
         elif direct == 'ref':
@@ -388,18 +398,21 @@ class GenerateCitationNet():
             if level == 2 & len(dfRes) >= 0:
                 if debug:
                     print(f'Got {dfRes.shape[0]} references, looking for second level.')
-                newDFs = [dfRes]
-                for elem in dfRes.targetDOI.values:
-                    dfResTemp, runtime = self.getReferenceDF(elem)
-                    runtimeTotal.append(runtime)
-                    newDFs.append(dfResTemp)
-                dfRes = pd.concat(newDFs, ignore_index=True)
-                dfRes.targetDOI.replace(
-                    r'^\s*$', np.nan, regex=True, inplace=True
-                    )
-                dfRes.targetDOI.fillna(
-                    value=dfRes.targetFull, inplace=True
-                    )
+                if 'targetDOI' in dfRes.columns:
+                    newDFs = [dfRes]
+                    for elem in dfRes.targetDOI.values:
+                        dfResTemp, runtime = self.getReferenceDF(elem)
+                        runtimeTotal.append(runtime)
+                        newDFs.append(dfResTemp)
+                    dfRes = pd.concat(newDFs, ignore_index=True)
+                    dfRes.targetDOI.replace(
+                        r'^\s*$', np.nan, regex=True, inplace=True
+                        )
+                    dfRes.targetDOI.fillna(
+                        value=dfRes.targetFull, inplace=True
+                        )
+                else:
+                    dfRes.insert(0, 'targetDOI', dfRes.targetFull)
                 if debug:
                     print(f'Ref: Runtime {sum(runtimeTotal)} sec.')
         elif direct == 'both':
